package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````4"-```````!``````````%"S````
M`````````$``.``)`$``'@`=``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````'2?````````=)\`````````
M`"````````$````&````T*T```````#0K6```````-"M8```````:`0`````
M``#8%```````````(````````@````8```#HK0```````.BM8```````Z*U@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````0)D```````!`F4```````$"90```````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````-"M````````T*U@``````#0K6``
M`````#`"````````,`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,```````````````0`
M```4`````P```$=.50!AQ=IEEJAZ.=&S,`X7SD$MPS1:?&$```!E````````
M````````````!```````````````-0`````````<````)P```!T`````````
M/`````D```!2`````````!0```!&````1P```#X```!6````8@````8````]
M```````````````#````60```#L``````````````$H```!0````30```#@`
M````````9````$D`````````+@`````````V`````````!\```!8````10``
M`#<``````````````%T`````````$P````<``````````````$\````D````
M,````"@```````````````@`````````&``````````````````````````!
M````(@````H```!`````5````#\``````````````%H```!,````*0```%4`
M``!(````,P```"\`````````00```````````````````%P```!+````````
M`"H```!1````,@````L```!3`````@``````````````````````````````
M`````````````````````````````````````%X`````````````````````
M```````````````````````````````5`````````&,``````````````!8`
M````````````````````````80```!(````9````&@```!$`````````7P``
M`%<````F````0P`````````E```````````````7````+````!X```!@````
M```````````````````````````C````````````````````.@`````````Y
M````0@```#$````T````6P````````````````````````````````````\`
M```,````+0`````````%````&P```"``````````(0``````````````*P``
M`!`````-````````````````````3@``````````````````````````````
M#@``````````````1```````````````$0```$(````$````"````"`<$``%
M0`2&*`)``)"&`8C"*0`@22`$"[BB.$6Z!`(*0@```$,```!'````2P```$P`
M``!2````5````%8```!:````7`````````!>````80```&(```!C````````
M``````![\$IK;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5DU'S9<5@<
MXD?&`:Q+X\"ZXY)\PN4_+/JA;&"S`8MO:@E#UH?YG(%FK\QFQ;F<0$)%U>S$
MB060B`=PTSGRBQP,%.*>R=6R<=K-XYXS8MOM##J7"U:DFY:GW:-K?ZF<F^&G
M`@H*BA!7H^#[20```````````````````````````````"L!```2````````
M`````````````````/(!```2`````````````````````````'$"```2````
M`````````````````````$8"```2``````````````````````````P````@
M`````````````````````````'@"```2``````````````````````````0#
M```2`````````````````````````+<````2````````````````````````
M`(T"```2`````````````````````````.P"```2````````````````````
M`````.0"```2`````````````````````````),````2````````````````
M`````````.L#```2`````````````````````````"8!```2````````````
M`````````````+`"```2`````````````````````````)L"```2````````
M`````````````````&`"```2`````````````````````````/T"```2````
M`````````````````````!H#```2`````````````````````````($!```2
M`````````````````````````$\!```2`````````````````````````*("
M```2`````````````````````````,4````2````````````````````````
M`,L!```2`````````````````````````!\"```2````````````````````
M`````%<"```2`````````````````````````"\"```2````````````````
M`````````$X"```2`````````````````````````+@!```2````````````
M`````````````(8"```2`````````````````````````.T!```2````````
M`````````````````$\#```2`````````````````````````$@#```2````
M`````````````````````%T!```2``````````````````````````T#```2
M`````````````````````````"@````@`````````````````````````,0"
M```2`````````````````````````',````2````````````````````````
M``L"```2`````````````````````````,0!```2````````````````````
M`````*(````2`````````````````````````'8!```2````````````````
M`````````&4````2`````````````````````````#`!```2````````````
M`````````````,L"```2`````````````````````````*T!```2````````
M`````````````````/,````2`````````````````````````'X"```2````
M``````````````````````\!```2`````````````````````````.8!```2
M`````````````````````````#D#```2`````````````````````````"$#
M```2`````````````````````````(\!```2````````````````````````
M`$$#```2`````````````````````````)0"```2````````````````````
M`````#<````@`````````````````````````-<````2````````````````
M`````````&T!```2`````````````````````````-D"```2````````````
M`````````````$$"```2``````````````````````````,"```2````````
M`````````````````+8"```2`````````````````````````$L````@````
M`````````````````````*D"```2`````````````````````````"L#```2
M`````````````````````````)T!```2````L!U``````````````````/0#
M```2``\`@%=```````!O`````````,(#```2`!``A%A`````````````````
M`!D$```2``\`L$A```````!^"P```````%P#```2``\`0"%````````,`@``
M`````,@#```2``\`8$)````````%`````````(<$```2``\`<$)```````"S
M`0```````($$```2``P`^!Q``````````````````+0$```2``\`,%1`````
M``!!`P```````'(#```0`!L`.+)@```````````````````$```2``\`,$1`
M```````D`````````#,$```1`!$`D%A````````$`````````'X#```0`!L`
MJ,)@`````````````````'\$```2``\`($%````````J`````````)0$```2
M``\`D$=````````?`0```````*8$```2``\``$=```````!4`````````"8$
M```0`!H`&+)@`````````````````((````2````@"!`````````````````
M``T$```2``\`8$1```````"_`````````&$#```1`!L`4+)@```````(````
M`````&L#```0`!H`.+)@`````````````````&(#```A`!L`4+)@```````(
M`````````&@$```1`!H`,+)@```````(`````````/8"```1`!L`6+)@````
M```(`````````+@#```2``\`@%A````````"`````````#P!```2````P!]`
M`````````````````%@$```2``\`$%A```````!E`````````"P$```2``\`
M4"-````````J`````````"@$```@`!H`&+)@``````````````````0!```1
M`!L`0+)@```````$`````````&,#```A`!L`4+)@```````(`````````-D#
M```2``\`8$=````````D`````````$($```2``\`H$%```````"Y````````
M`.8````1`!L`2+)@```````!`````````'($```2``\`($5```````#;`0``
M``````!L:6)P97)L+G-O`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!0
M97)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!097)L7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V
M7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E
M<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB<'1H<F5A9"YS;RXP`&]P96XV
M-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET
M`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U
M;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L
M96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?
M7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D
M97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D
M:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI
M8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L:6(O<&5R;#4O-2XQ."XR+W@X-E\V-"UL:6YU>"UT:')E860M
M;75L=&DO0T]210!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S
M96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?
M24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S
M=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN
M9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0``````@`#``(``@````(``@``
M``(``@`"`````@````(``@`$``(``@```````@```````P`"``4``@````(`
M`P`"``(````&````!P````,``@````````````8```````(````#``(``@``
M``(``@`````````"``(``P`&`````@`&`````0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0````$``@`!``(``0`"``$````!``$``0````(``0`!
M`````0````$``0#6`0``$````"````!U&FD)```#`,H$`````````0`%`"4"
M```0`````````)21E@8```<`U@0``!````!T&6D)```&`.$$```0````<AEI
M"0``!0#M!```$````!1I:0T```0`^00``!````!U&FD)```"`,H$````````
M^*]@```````&````)```````````````0+)@```````%````7P``````````
M````2+)@```````%````8P``````````````4+)@```````%````50``````
M````````6+)@```````%````60``````````````&+!@```````'`````0``
M````````````(+!@```````'`````@``````````````*+!@```````'````
M`P``````````````,+!@```````'````!```````````````.+!@```````'
M````!@``````````````0+!@```````'````!P``````````````2+!@````
M```'````"```````````````4+!@```````'````"0``````````````6+!@
M```````'````0@``````````````8+!@```````'````"@``````````````
M:+!@```````'````"P``````````````<+!@```````'````#```````````
M````>+!@```````'````#0``````````````@+!@```````'````#@``````
M````````B+!@```````'````#P``````````````D+!@```````'````$```
M````````````F+!@```````'````$0``````````````H+!@```````'````
M$@``````````````J+!@```````'````$P``````````````L+!@```````'
M````%```````````````N+!@```````'````%0``````````````P+!@````
M```'````%@``````````````R+!@```````'````%P``````````````T+!@
M```````'````&```````````````V+!@```````'````&0``````````````
MX+!@```````'````&@``````````````Z+!@```````'````&P``````````
M````\+!@```````'````'```````````````^+!@```````'````'0``````
M`````````+%@```````'````'@``````````````"+%@```````'````'P``
M````````````$+%@```````'````(```````````````&+%@```````'````
M(0``````````````(+%@```````'````(@``````````````*+%@```````'
M````(P``````````````,+%@```````'````)0``````````````.+%@````
M```'````)@``````````````0+%@```````'````)P``````````````2+%@
M```````'````*```````````````4+%@```````'````*0``````````````
M6+%@```````'````*@``````````````8+%@```````'````6P``````````
M````:+%@```````'````*P``````````````<+%@```````'````+```````
M````````>+%@```````'````+0``````````````@+%@```````'````+@``
M````````````B+%@```````'````+P``````````````D+%@```````'````
M,```````````````F+%@```````'````,0``````````````H+%@```````'
M````,@``````````````J+%@```````'````,P``````````````L+%@````
M```'````-```````````````N+%@```````'````-0``````````````P+%@
M```````'````4P``````````````R+%@```````'````-@``````````````
MT+%@```````'````-P``````````````V+%@```````'````.0``````````
M````X+%@```````'````.@``````````````Z+%@```````'````.P``````
M````````\+%@```````'````/```````````````^+%@```````'````/0``
M`````````````+)@```````'````/@``````````````"+)@```````'````
M0```````````````$+)@```````'````00``````````````2(/L"$B+!?62
M(`!(A<!T!>@C!```2(/$",,``````````````````/\UXI(@`/\EY)(@``\?
M0`#_)>*2(`!H`````.G@_____R7:DB``:`$```#IT/____\ETI(@`&@"````
MZ<#_____)<J2(`!H`P```.FP_____R7"DB``:`0```#IH/____\ENI(@`&@%
M````Z9#_____);*2(`!H!@```.F`_____R6JDB``:`<```#I</____\EHI(@
M`&@(````Z6#_____)9J2(`!H"0```.E0_____R62DB``:`H```#I0/____\E
MBI(@`&@+````Z3#_____)8*2(`!H#````.D@_____R5ZDB``:`T```#I$/__
M__\E<I(@`&@.````Z0#_____)6J2(`!H#P```.GP_O___R5BDB``:!````#I
MX/[___\E6I(@`&@1````Z=#^____)5*2(`!H$@```.G`_O___R5*DB``:!,`
M``#IL/[___\E0I(@`&@4````Z:#^____)3J2(`!H%0```.F0_O___R4RDB``
M:!8```#I@/[___\E*I(@`&@7````Z7#^____)2*2(`!H&````.E@_O___R4:
MDB``:!D```#I4/[___\E$I(@`&@:````Z4#^____)0J2(`!H&P```.DP_O__
M_R4"DB``:!P```#I(/[___\E^I$@`&@=````Z1#^____)?*1(`!H'@```.D`
M_O___R7JD2``:!\```#I\/W___\EXI$@`&@@````Z>#]____)=J1(`!H(0``
M`.G0_?___R72D2``:"(```#IP/W___\ERI$@`&@C````Z;#]____)<*1(`!H
M)````.F@_?___R6ZD2``:"4```#ID/W___\ELI$@`&@F````Z8#]____):J1
M(`!H)P```.EP_?___R6BD2``:"@```#I8/W___\EFI$@`&@I````Z5#]____
M)9*1(`!H*@```.E`_?___R6*D2``:"L```#I,/W___\E@I$@`&@L````Z2#]
M____)7J1(`!H+0```.D0_?___R5RD2``:"X```#I`/W___\E:I$@`&@O````
MZ?#\____)6*1(`!H,````.G@_/___R5:D2``:#$```#IT/S___\E4I$@`&@R
M````Z<#\____)4J1(`!H,P```.FP_/___R5"D2``:#0```#IH/S___\E.I$@
M`&@U````Z9#\____)3*1(`!H-@```.F`_/___R4JD2``:#<```#I</S___\E
M(I$@`&@X````Z6#\____)1J1(`!H.0```.E0_/___R42D2``:#H```#I0/S_
M__\E"I$@`&@[````Z3#\____)0*1(`!H/````.D@_/___R7ZD"``:#T```#I
M$/S___\E\I`@`&@^````Z0#\____)>J0(`!H/P```.GP^____R7"CB``9I``
M`````````%-(@^PPB7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`CH"?[_
M_[K`'T``OX`@0`!(B=;H=S8``(`]R)`@``!U+^@9_?__2(7`2(D%#Z$@``^$
MI@$``$B)Q^A!_/__BSV;D"``Z-;]___&@)4(````BSV)D"``Z,3]__^`B*X$
M```"BSUWD"``Z++]__^`B*X$```!BT0D'(UX!4AC_TB%_P^(&`$``/)(#RK'
M\@]8!3MW``!F#RX%.W<```^'1`$``$C!YP/HY/S__TB+3"002(D%<*`@`,<%
M;J`@``0```!(BQ%(QT`(>5I``$C'0!A\6D``2(D02(L5\8\@`$B)4!"+5"0<
M@_H!?B>-<OY,C03U"````#'V#Q^``````$B+?#$(2(E\,"!(@\8(3#G&=>V-
M2@1(BSTCH"``@\(#13'`OE!!0`!(8\E(QT3(^`````!(B<'H9/W__X7`B<-T
M.TB+/?>?(`#HLOO__TB-="0L,<"_/5E``.AQ&```2(7`="E(BSW5GR``Z##[
M___H^_S__TB#Q#")V%O#2(L]O)\@`.C7_?__B</KM4B+/:2?(`!(A?]T).B"
M-```Z\1(B?A(B?I(T>B#X@%("=#R2`\JP/(/6,#IT/[__TB-="0LO_)80`#H
M!!@``$B%P$B)!6*?(`!TC$B)Q^N\OP$```#HF?W__^CD_/__#Q]``#'M28G1
M7DB)XDB#Y/!05$G'P(!80`!(Q\$06$``2,?'0"%``.BG^___]&8/'T0``+@_
MLF``54@M.+)@`$B#^`Y(B>5W`EW#N`````!(A<!T]%V_.+)@`/_@#Q^`````
M`+@XLF``54@M.+)@`$C!^`-(B>5(B<)(P>H_2`'02-'X=0)=P[H`````2(72
M=/1=2(G&OSBR8`#_X@\?@`````"`/6F.(```=1%52(GEZ'[___]=Q@56CB``
M`?/##Q]``$B#/<B)(```=!ZX`````$B%P'045;_@K6``2(GE_]!=Z7O___\/
M'P#I<____P\?`$%73(U'.#')059!54%455-(@>P0`@``9@\?A```````28L4
M"$B)T$B)UDC!X`A(P>88)0``_P")]D@)\$B)UDC![@B!Y@#_``!("?!(B=9(
MP>X80`^V]D@)\$B)UDC![B!(B41,B$B)\$C!YAA(P>`(B?8E``#_`$@)\$B)
MUDC!ZCA(P>XH@>8`_P``2`GP2`G02(E$3)!(@\$(2(/Y0`^%>____TB-1"2(
M2(VT)/`!``!(C5!H9BX/'X0``````$B+0MA(,P)(@\((2#-"H$@S0I!(B<%(
M`<!(P>D?2`G!@^'_2(E*$$@Y\G742(L73(MO($R+3PA,BU<03(MG&$R)Z4B)
MT$@#3"2(2(G62,'H&TR)S4C!Y@5(P>T"38G@2`GP3`-$))!(B=:)P$CWUDF)
MUDR-G`&9>8):3(G(3(G12/?03"')3"'63"'@2<'N`DR)TT@)R$@#7"2820'#
M3(G(2,'@'D2)V4@)Q8GM2(GH2"'02`GP2(G.38V$`)EY@EI(B<A(P>X;2,'@
M!4@)QDB)T$C!X!Z)]DD)QDB)R$D!\$6)]DCWT$2)QDTA\T@AZ$P)V$R-G`.9
M>8):2(GP2(GS2,'C!4C!Z!M("=A(B<M(P>$>B<!(P>L"20'#2`G+2`-L)*!(
MB?&)VT2)V$CWT4DAV$PA\4P#="2H3`G!3(V$#9EY@EI(B<%(B<5(P>4%2,'I
M&T@)Z4B)]4C!YAY(P>T"B<E("?5(B<9)`<B)[4CWUD2)P4@AWDDAZT@#7"2P
M3`G>38V<-IEY@EI(B<Y)B<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)"<9(
MB<A)`?-%B?9(]]!$B=Y-(?!((>A,"<!,C80#F7F"6DB)\$B)\TC!XP5(P>@;
M2`G82(G+2,'A'HG`2,'K`DD!P$@)RT@#;"2X2(GQB=M$B<!(]]%)(=M,(?%,
M`W0DP$P)V4R-G`V9>8):2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)
M2`GU2(G&20'+B>U(]]9$B=E((=Y)(>A(`UPDR$P)QDV-A#:9>8):2(G.28G.
M2<'F!4C![AM,"?9)B<9(P>`>2<'N`HGV20G&2(G(20'P18GV2/?01(G&32'S
M2"'H3`G83(V<`YEY@EI(B?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)P$C!ZP))
M`<-("<M(`VPDT$B)\8G;1(G82/?122'83"'Q3`-T)-A,"<%,C80-F7F"6DB)
MP4B)Q4C!Y05(P>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)QDD!R(GM2/?61(G!
M2"'>22'K2`-<).!,"=Y-C9PVF7F"6DB)SDF)SDG!Y@5(P>X;3`GV28G&2,'@
M'DG![@*)]DD)QDB)R$D!\T6)]DCWT$2)WDTA\$@AZ$P)P$R-A`.9>8):2(GP
M2(GS2,'C!4C!Z!M("=A(B<M(P>$>B<!(P>L"20'`2`G+2`-L).A(B?&)VT2)
MP$CWT4DAVTPA\4P#="3P3`G93(V<#9EY@EI(B<%(B<5(P>4%2,'I&T@)Z4B)
M]4C!YAY(P>T"B<E("?5(B<9)`<N)[4CWUD2)V4@AWDDAZ$@#7"3X3`G&38V$
M-IEY@EI(B<Y)B<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)"<9(B<A)`?!%
MB?9(]]!$B<9-(?-((>A,"=A)B?-(C9P#F7F"6DB)\$G!XP5(P>@;3`G828G+
M2,'A'HG`2<'K`D@!PTD)RT@#+"1(B?%%B=N)V$CWT4TAV$PA\4P#="0(3`G!
M3(V$#9EY@EI(B<%(B<5(P>4%2,'I&T@)Z4B)]4C!YAY(P>T"B<E("?5(B<9)
M`<B)[4CWUD2)P4PAWD@AZTP#7"002`G>28V<-IEY@EI(B<Y)B<Y)P>8%2,'N
M&TP)]DF)QDC!X!Y)P>X"B?9)"<9(B<A(`?-%B?9(]]")WDTA\$@AZ$P)P$V-
MA`.9>8):2(GP28GS2<'C!4C!Z!M,"=A)B<M(P>$>B<!)P>L"20'`20G+2`-L
M)!A(B?%%B=M$B<!(]]%,(=M,(?%,`W0D($@)V4B)PTB-K`V9>8):2(G!2,'C
M!4C!Z1M("=F)R4@!S4B)\4C!YAY(P>D"B>M("?%(B<9!B<](]]9-(?A,(=Y,
M`UPD*$P)QDF)V$P#?"0P38VT-IEY@EI(B=Y)P>`%2,'N&TP)QHGV20'V2(G&
M2,'@'DC![@)%B?!("<9,B<!(,?%(P>@;,<U,B<%(P>$%28VL*Z'KV6Y("<A(
MB=E(P>,>2,'I`HG`2`G92`'%2(G(08GK2#'P3(G;B?9!,<9,B=A(P>,%2,'H
M&T^-M#>AZ]EN2`-T)#A("=B)P$D!QDR)P$G!X!Y(P>@"1(GS3`G`28G`23'(
MB<E(`TPD0$0QQ4F)V$B-K"ZAZ]EN2(G>2<'@!4C![AM,"<:)]D@!]4R)WDG!
MXQY(P>X"08GH3`G>28GS23'#B<!(`T0D2$4QWDV)PTZ-M#&AZ]EN3(G!2<'C
M!4C!Z1M,"=F)R4D!SDB)V4C!XQY(P>D"18GS2`G92(G+2#'SB?8QW4R)VTB-
MK"BAZ]EN3(G82,'H&TC!XP5(`W0D4$@)V(G`2`'%3(G`2<'@'DC!Z`*)ZTP)
MP$F)P$DQR(G)2`-,)%A%,<9)B=A.C;0VH>O9;DB)WDG!X`5(P>X;3`G&B?9)
M`?9,B=Y)P>,>2,'N`D6)\$P)WDF)\TDQPXG`2`-$)&!$,=U-B<-(C:PIH>O9
M;DR)P4G!XP5(P>D;3`G9B<E(`<U(B=E(P>,>2,'I`D&)ZT@)V4B)RT@Q\XGV
M03'>3(G;3HVT,*'KV6Y,B=A(P>,%2,'H&T@)V(G`20'&3(G`2,'H`DG!X!Y(
M`W0D:$P)P$2)\TF)P$DQR(G)2`-,)'!$,<5)B=A(C:PNH>O9;DB)WDG!X`5(
MP>X;3`G&B?9(`?5,B=Y)P>,>2,'N`D&)Z$P)WDF)\TDQPXG`2`-$)'A%,=Y-
MB<-.C;0QH>O9;DR)P4G!XP5(P>D;3`G9B<E)`<Y(B=E(P>,>2,'I`D6)\T@)
MV4B)RT@Q\XGV,=U,B=M(C:PHH>O9;DR)V$C!XP5(P>@;2`G8B<!(`<5,B<!)
MP>`>2,'H`HGK3`G`2`.T)(````!)B<!),<B)R4@#C"2(````13'&28G83HVT
M-J'KV6Y(B=Y)P>`%2,'N&TP)QHGV20'V3(G>2<'C'DC![@)%B?!,"=Y)B?-)
M,<.)P$@#A"20````1#'=38G#2(VL*:'KV6Y,B<%)P>,%2,'I&TP)V8G)2`'-
M2(G92,'C'DC!Z0)!B>M("=E(B<M(,?.)]D@#M"28````03'>3(G;3HVT,*'K
MV6Y,B=A(P>,%2,'H&T@)V(G`20'&3(G`2<'@'DC!Z`)$B?-,"<!)B<!),<B)
MR40QQ4F)V$B-K"ZAZ]EN2(G>2,'N&TG!X`5(`XPDH````$P)QHGV2`'U3(G>
M2<'C'DC![@)!B>A,"=Y)B?-),<.)P$@#A"2H````13'>38G#3HVT,:'KV6Y,
MB<%)P>,%2,'I&TP)V8G)20'.2(G92,'C'DC!Z0)%B?-("=E(B<M(,?.)]D@#
MM"2P````,=U,B=M(C:PHH>O9;DR)V$C!XP5(P>@;2`G8B<!(`<5,B<!)P>`>
M2,'H`HGK3`G`28G`23'(B<E%,<9)B=A.C;PVH>O9;DB)WDG!X`5(P>X;3`G&
M38G8B?9)`?=)P>,>2<'H`DT)V$@#C"2X````18G^3(G&2#'&B<!(`X0DP```
M`#'U3(GV3(V<*:'KV6Y,B?%(P>8%2,'I&T@)\4B)WDC!XQY(P>X"B<E("=Y)
M`<M(B?%$B=U,,<%%B<!!,<](B>E.C;PXH>O9;DB)Z$C!X05(P>@;2`G(3(GQ
M2<'F'HG`2,'I`DD!Q[C<O!N/3`GQ28G&3`.T),@```!$B?M-`?!)B<Y)"?9-
M(?-)B<Y)(?:)]D4)\T^--!A)B=A)B=M)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!
MY1Y)P>@"18GS20GH2(G%2`.L)-````!(`>Y,B<5("<U)(>],B<5((<V)R4$)
M[TR)W4D!]TR)WDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)
MPT@#G"38````2`'92(GS3`G#22'>2(GS3"'#18G`00G>2(GK20'.2(GI2,'C
M!4C!Z1M("=F)R4D!SDR)V4G!XQY(P>D"1(GS3`G928G#3`.<).````!-`=A)
MB<M)"?--(=])B<M)(?.)]D4)WTF)VTT!QTF)V$G!XP5)P>@;30G818G`30''
M28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPDZ````$@![DR)Q4@)S4DA[DR)Q4@A
MS8G)00GN3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!XQY(P>X"1(GU
M2`G>2(G#2`.<)/````!(`=E(B?-,"<-)(=](B?-,(<-%B<!!"=](B>M)`<](
MB>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPD^```
M`$T!V$F)RTD)\TTAWDF)RTDA\XGV10G>28G;30'&28G82<'C!4G!Z!M-"=A%
MB<!-`<9)B>A(P>4>2<'H`D6)\TD)Z$B)Q4@#K"0``0``2`'N3(G%2`G-22'O
M3(G%2"'-B<E!">],B=U)`?=,B=Y(P>4%2,'N&T@)[HGV20'W2(G>2,'N`DC!
MXQY$B?U("=Y(B<-(`YPD"`$``$@!V4B)\TP)PTDAWDB)\TPAPT6)P$$)WDB)
MZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>2,'I`D2)\TP)V4F)PTP#
MG"00`0``30'828G+20GS32'?28G+22'SB?9%"=])B=M-`<=)B=A)P>,%2<'H
M&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L)!@!``!(`>Y,B<5(
M"<U)(>Y,B<5((<V)R4$)[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(
MP>,>2,'N`D2)]4@)WDB)PT@#G"0@`0``2`'92(GS3`G#22'?2(GS3"'#18G`
M00G?2(GK20'/2(GI2,'C!4C!Z1M("=F)R4D!STR)V4G!XQY(P>D"1(G[3`G9
M28G#3`.<)"@!``!-`=A)B<M)"?--(=Y)B<M)(?.)]D4)WDF)VTT!QDF)V$G!
MZ!M)P>,%30G818G`30'&28GH2,'E'DG!Z`)%B?-)">A(B<5(`ZPD,`$``$@!
M[DR)Q4@)S4DA[TR)Q4@AS8G)00GO3(G=20'W3(G>2,'E!4C![AM(">Z)]DD!
M]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<)#@!``!(`=E(B?-,"<-)(=Y(B?-,
M(<-%B<!!"=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92,'I`DG!XQY$
MB?-,"=E)B<-,`YPD0`$``$T!V$F)RTD)\TTAWTF)RTDA\XGV10G?28G;30''
M28G82<'C!4G!Z!M-"=A%B<!-`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"1(
M`0``2`'N3(G%2`G-22'N3(G%2"'-B<E!">Y,B=U)`?9,B=Y(P>4%2,'N&T@)
M[HGV20'V2(G>2,'C'DC![@)$B?5("=Y(B<-(`YPD4`$``$@!V4B)\TP)PTDA
MWTB)\TPAPT6)P$$)WTB)ZTD!STB)Z4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>
M2,'I`D2)^TP)V4F)PTP#G"18`0``2`.$)&`!``!-`=A)B<M)"?--(=Y)B<M)
M(?.)]D4)WDF)VT@!\$T!QDF)V$G!XP5)P>@;30G818G`30'&28GH2,'E'DG!
MZ`)%B?-)">A,B<9("<Y)(?=,B<9((<Z)R4$)]TR)WDD!QTR)V$C!Z!M(P>8%
M2`GP2(G>2,'C'HG`2,'N`DD!Q[C6P6+*2`G>2(G#2`.<)&@!``!$B?U(`=E(
MB?-,,<-%B<!!,=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92<'C'DC!
MZ0)$B?-,"=E)B<-,`YPD<`$``$T!V$F)RTDQ\XGV13'?28G;30''28G82<'C
M!4G!Z!M-"=A%B<!-`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"1X`0``2`'N
M3(G%2#'-B<E!,>Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC!
M[@)$B?5("=Y(B<-(`YPD@`$``$@!V4B)\TPQPT6)P$$QWTB)ZTD!STB)Z4C!
MXP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"2(`0``30'8
M28G+23'SB?9%,=Y)B=M-`<9)B=A)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!Y1Y)
MP>@"18GS20GH2(G%2`.L))`!``!(`>Y,B<5(,<V)R4$Q[TR)W4D!]TR)WDC!
MY05(P>X;2`GNB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)PT@#G"28`0``2`'9
M2(GS3#'#18G`03'>2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!XQY(
MP>D"1(GS3`G928G#3`.<)*`!``!-`=A)B<M),?.)]D4QWTF)VTT!QTF)V$G!
MXP5)P>@;30G818G`30''28GH2<'H`DC!Y1Y%B?M)">A(B<5(`ZPDJ`$``$@!
M[DR)Q4@QS8G)03'N3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!XQY(
MP>X"1(GU2`G>2(G#2`.<)+`!``!(`=E(B?-,,<-%B<!!,=](B>M)`<](B>E(
MP>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPDN`$``$T!
MV$F)RTDQ\XGV13'>28G;30'&28G82<'H&TG!XP5-"=A%B<!-`<9)B>A(P>4>
M2<'H`D6)\TD)Z$B)Q4@#K"3``0``2`'N3(G%2#'-B<E!,>],B=U)`?=,B=Y(
MP>4%2,'N&T@)[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPDR`$``$@!
MV4B)\TPQPT6)P$$QWDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>
M2,'I`D2)\TP)V4F)PTP#G"30`0``30'828G+23'SB?9%,=])B=M-`<=)B=A)
MP>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L)-@!``!(
M`>Y,B<5(,<V)R4$Q[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>
M2,'N`D2)]4@)WDB)PT@#G"3@`0``2`'92(GS3#'#18G`03'?2(GK20'/2(GI
M2,'C!4C!Z1M("=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<).@!``!-
M`=A)B<M),?.)]D4QWDF)VTT!QDF)V$G!XP5)P>@;30G818G`30'&28GH2,'E
M'DG!Z`)%B?-)">A(B<5(`ZPD\`$``$@![DR)Q4@QS8G)03'O3(G=20'W3(G>
M2,'E!4C![AM(">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<)/@!``!(
M`=E(B?-,,<-%B<!!,=Y*C1PQ2(GI28GN2<'F!4C!Z1M,"?$!RTR)V4C!Z0))
MP>,>2`.$)``"``!,"=E)B>M(P>4>2<'K`D$!V4D)ZTB)W4P!P$F)R$C!Y05)
M,?!$`>%$`>Y%,<=%`=I.C00X2(G82,'H&T@)Z$0!P`'"2(D73(E/"$R)5Q!(
MB4\82(EW($B!Q!`"``!;74%<05U!7D%?PP\?@`````!!5T%6055)B?U!5%53
M2(/L"$B%_W1H3(LU`W<@`$V%]G1<#[8'28GW/#UT9(3`=&!)B?Q)@\0!00^V
M!"0\/70$A,!U[T4I[$F+'DB%VW0O36/D3(GU#Q\`3(GB3(GN2(G?Z,KA__^%
MP'4'0H`\(SUT)TB#Q0A(BUT`2(7;==I(@\0(,<!;74%<05U!7D%?PY!%,>3K
ML@\?`$PI]4J-1",!2,']`T&)+TB#Q`A;74%<05U!7D%?PV8N#Q^$``````!3
M2(G[2(/L$`\?A```````2(UT)`PQP$B)W^@A____2(7`="Y(8U0D#$B+!3!V
M(`!(C0302(M0"$B%TDB)$'302(/`"$B+4`A(A=)(B1!U\.N^2(/$$%O##Q^$
M``````!!5S'`059!54%428G\55-(B?-(@^PH@#X]#Y3`2`'#2(G?Z*GA__](
MC70D'$F)Q4R)YS'`Z*?^__](A<!(B<4/A/L```!(B<?H@^'__TDYQ0^&T@``
M`$QC="0<2<'F`T$/M@0D/#T/A)0!``"$P`^$C`$``$R)X>L,#Q^``````$"$
M]G0-2(/!`0^V,4"`_CUU[DPIX4ACR4P#-6%U(`!*C7PI`NB7XO__2(7`28D&
M#X1>`0``2&-4)!Q(BP4_=2``28U,)`%(BQ3000^V!"2$P(@"=1WK'V8/'X0`
M`````$B#P0$/MD'_2(/"`83`B`)T!#P]=>K&`CTQP`\?1```#[8,`XA,`@%(
M@\`!A,EU\#'`2(/$*%M=05Q!74%>05_##Q^``````$B#PP$/MD/_2(/%`83`
MB$7_=>WKTP\?`$R+/;ET(`!)@S\`#X2V````3(GX,>UF+@\?A```````2(/`
M"(/%`4B#.`!U\XUU`DAC]DC!Y@.+!;.$(`"%P'0W3(G_Z$?B__](A<!(B05M
M="``='Y(8\U)B<!,C33-`````$G'1,@(`````(EL)!SIJO[__P\?`$B)]\<%
M:X0@``$```#H=N'__TB%P'1$2&/-3(G^2(G'3(TTS0````!(B4PD"$R)\N@3
MXO__2(M,)`A)B<!(B04$="``ZZ5FD#')Z9'^__^^$````#'MZ63___^X____
M_^GU_O__#Q\`055!5%5(B?U32('LF````$B%_W0%@#\`=19(@<28````6UU!
M7$%=PP\?A```````Z"O?__](A<!)B<1TW4R)Y^BKX?__2(7`2(G##X2?````
M@'L3+@^$M0```$B#PQ-(B>_H2=___TB)WTF)Q>@^W___08U\!0)(8__HH>#_
M_TF)V4F)Q4B)QTF)Z+F46$``2,?"_____[X!````,<#H#>+__[\!````2(GB
M3(GNZ)W>__^#^/],B>]T$(M$)!@E`/```#T`0```=&WH$-[__TR)[^CHW?__
M3(GGZ!#A__](A<!(B<,/A67___\/'T``3(GGZ%C?__](B>_HH-[__TB!Q)@`
M``!;74%<05W#9I`/MD,4A,`/A"'___\\+@^%-____X![%0`/A`____]FD.DF
M____#Q\`Z,/^__\/'P#KC@\?0`!F+@\?A```````4TB)^XL]=G(@`.BQW___
M2(V0X`$``$B)WK\!````Z.W@__^%P'0),<!;PP\?1```BSU*<B``Z(7?__^+
M@/@!```E`/```#T`0```=!V+/2UR(`#H:-___XN`^`$``"4`\```/0"@``!U
MO4B)W[X"````Z%G@__^%P`^4P`^VP%O##Q]$``!F+@\?A```````052Z_P\`
M`$F)]%5(B?V_FEA``%-(@>P0$```2(GF9$B+!"4H````2(F$)`@0```QP.CZ
MW/__A<!^;HU(_TACV8`\'`!T6DACV$B)VKXO````2(GGZ%?>__](A<!T2HL]
MC'$@`.C'WO__2(G92(GB2(GN2(G'Z.;?__](BX0D"!```&1(,P0E*````'4V
M2('$$!```%M=05S##Q^``````(7)=:4/'T``BSU"<2``Z'W>__],B>)(B>Y(
MB<?H7]W__^NWZ!C=__\/'X0``````$B#[`B+/19Q(`#H4=[__[FI6$``NK`=
M0`"^LUA``$B)QTB#Q`CI9M[__V8/'T0``$B#[`B+/>9P(`#H(=[__TB)Q^BY
M____BSW3<"``Z`[>__]!N'-:0`!%,<FZ,%1``$R)P;[/6$``2(G'2(/$".E\
MWO__9I!F+@\?A```````4TB!["`@``!D2(L$)2@```!(B80D&"```#'`Z.#;
M__]!N:580`!!B<"YY%A``#'`N@$0``"^`0```$B)Y^@^W___A<!X:DB-M"00
M$```N@`0``!(B>?HA=O__X7`2(G#>$Z->`%(8__H@]W__TB%P'0^2&/;2(VT
M)!`0``!(B<=(B=KH.-W__\8$&`!(BY0D&"```&1(,Q0E*````'452('$("``
M`%O##Q^$```````QP.O8Z-?;__\/'X``````Z3O___^09BX/'X0``````$%5
M051)B?R_\EA``%532(GS2('L.!```&1(BP0E*````$B)A"0H$```,<!(C70D
M'.B+^/__OB\```!,B>=(B<7HF]O__TB%P'0W3(GFO_M80``QP.B'^?__3(G@
M2(NT)"@0``!D2#,T)2@````/A3L!``!(@<0X$```6UU!7$%=PTR)Y^@GV___
M2(G?O@A90`!!B<7HE]W__TB)PP\?0`!(A=MTI8`[`+CP6$``2`]$V$B%[703
M2(G>2(GOZ/_;__^%P`^$H````$B)W^C?VO__B<%(F$B-5`/_@#HO=1"0Q@(`
M2(/J`8/I`8`Z+W3Q08U$#0$]_P\```^/2____TB-?"0@0;D*64``28G8N2E:
M0`"Z`!```+X!````,<!,B20DZ(G=__^+/:-N(`#HWMO__TB-="0@2(V0X`$`
M`+\!````Z`C:__^%P'4=BSU^;B``Z+G;__^+@/@!```E`/```#T`@```=!2^
M"%E``#'_Z+O<__](B</I(____TB-?"0@O@$```#HE-S__X7`==E(C70D(+_[
M6$``Z$'X__](C7PD(.C'VO__Z:[^___H#=K__P\?`&8N#Q^$```````/M@](
MB?B$R7082(U7`6:0@/DO#[8*2`]$PDB#P@&$R77N\\-FD&8N#Q^$``````!(
MA?]32(G[="^`/P!T*NBMV?__2(U4`_](.=-R#.M'D$B#Z@%(.=IT!X`Z+W3R
MZRV`.B]U?P\?`+\"````Z.[:__](A<!T:;HN````9HD06\,/'X``````@#HO
M=`E(@^H!2#G3<O)(.=IU"NO##Q\`@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`
M$```=R-(B=Y(@\(!N0`0``"_@+)@`.CMVO__N("R8`!;PV8/'T0``#'`6\-;
MOPI90`#IP=G__Y!(@^Q(OPQ90`!D2(L$)2@```!(B40D.#'`2(L%0!4``$B)
M1"002(L%/!4``$B)1"082(L%.!4``$B)1"0@2(L%-!4``$B)1"0H#[<%,!4`
M`&:)1"0P,<#H=/;__S'`OQ590`#H:/;__S'`OQU90`#H7/;__S'`OR990`#H
M4/;__S'`ORU90`#H1/;__S'`OSU90`#H./;__S'`O_)80`#H+/;__S'`OTE9
M0`#H(/;__S'`OU-90`#H%/;__S'`OUU90`#H"/;__S'`O_M80`#H_/7__S'`
MOV=90`#H\/7__S'`OW!90`#HY/7__TB-="0,,<"_>UE``.@3]?__2(7`=`](
MB<:_4UE``#'`Z!_V__](C70D##'`OXQ90`#H[O3__TB%P'0/2(G&OYY90``Q
MP.CZ]?__2(UT)`PQP+^I64``Z,GT__](A<!T/$B)QK_R6$``,<#HU?7__S'`
MOM590`"_+5E``.C$]?__2(M$)#AD2#,$)2@```!U6DB#Q$C##Q^``````$B-
M="0,,<"_N5E``.AW]/__2(7`=!)(B<:_25E``#'`Z(/U___KK)!(C70D(;_*
M64``N0H```#SIG682(UT)"N_25E``#'`Z%SU___KA>@UU___#Q]$``"+!2)K
M(`"#^/]T!<,/'T``2(/L&#'`OTE90`!(C70D#.@+]/__2(7`="8/MA`QP(32
M=`@QP(#Z,`^5P(D%YVH@`$B#Q!C#9BX/'X0``````#'`Z^=FD&8N#Q^$````
M``!(@^P(Z-?6__^)Q^B`UO__2(7`=`M(BP!(@\0(PP\?`#'`Z_1FD&8N#Q^$
M``````!!5T%628G^055!O>%90`!!5%6]UUE``%-(@^QH2,=$)"#A64``2,=$
M)"C764``3(UD)#!(QT0D,.190`!(QT0D.-I90`!(QT0D0-]90`!(QT0D2/%9
M0`!(QT0D4`````#K)F8/'T0``$B)Q^@0V?__2(7`=%-(A>UT/$F+!"1)B>U)
M@\0(2(G%2(UT)!PQP$R)[^@)\___2(7`2(G#3(GV=`6`.`!UP4R)[S'`Z`_T
M__](A>UUQ$B#Q&A;74%<05U!7D%?PP\?`$R)]^C`U?__2(G?28G'Z+75__])
MC7P'`N@;U___2(D<)$F)QTB)QT&Y"%E``$V)\+DI6D``2,?"_____[X!````
M,<#H@-C__TR)_DR)[S'`Z*/S___KDI!!5T%6055!5$F)_+_R6$``55-(@>R8
M@0``9$B+!"4H````2(F$)(B!```QP$B-="0\2,=$)$`(6D``2,=$)$CP6$``
M2,=$)%``````2,>$)(````">64``2,>$)(@```"764``2,>$))`````-6D``
M2,>$))@```"T64``2,>$)*`````56D``2,>$)*@`````````2,=$)&#\64``
M2,=$)&@96D``2,=$)'``````Z,SQ__](A<!T"8`X``^%1@0``#'`Z.?]__](
MA<!(B<,/A%($``!(B=_HD]3__TB-?``!Z/G5__^`.P!)B<5(B<5T,F8/'T0`
M`$0/M@-(B>\QP+DB6D``2,?"_____[X!````2(/#`4B#Q0+H4=?__X`[`'74
M2(VL)(@```"_GEE``.L2#Q]$``!(@\4(2(M]^$B%_W0[2(UT)#PQP.@O\?__
M2(7`2(G#=-^`.`!TVDB)Q^BJ]?__A<!TSDB)W^B^U/__2(7`2(G#=5]F#Q]$
M``!(BUPD0$B%VP^$6@$``(`[`+T!````=27I2P$```\?`$ACQ4B+7,1`2(7;
M#X0W`0``@\4!@#L`#X0K`0``2(G?Z$OU__^%P'372(G?Z%_4__](A<!(B<-T
MQTB)W^B/T___3(GIBS%(@\$$C9;__O[^]]8A\H'B@("`@'3HB=;![A#WPH"`
M```/1-9(C7$"2`]$S@#22(/9`TPIZ42-M`@$!```36/V3(GWZ++4__]!N0I9
M0`!(B<=(B<5)B=BY)UI``$C'PO____^^`0```#'`3(EL)`A(QP0D,%I``.@.
MUO__OL`!``!(B>_H4=+__X/X_W1\BST69R``Z%'4__](C9#@`0``2(GNOP$`
M``#HC=7__X7`#X2-````28L,)$B+/0)G(`!)B>BZZ%I``+X!````,<#HEM7_
M_S'`2(N4)(B!``!D2#,4)2@````/A9T(``!(@<28@0``6UU!7$%=05Y!7\,/
M'P`QV^GJ_O__D.B;T?__1(L(08/Y$0^$<O___TF+#"1(BSV;9B``28GHNJA:
M0`"^`0```#'`Z"_5__\QP.N7#Q\`BSUB9B``Z)W3__^+@/@!```E`/```#T`
M0```#X52____BSU!9B``Z'S3__^+F/P!``#H,=+__SG##X4T____BSTC9B``
MZ%[3__^+@/@!```E_P$``#W``0``#X43____3(GWZ%#3__](C70D/+_:64``
M2(G#,<#HW.[__TB%P$B)QP^$Q0<``.A[TO__28L\)$B)QNC_]?__2(7`28G%
M#X2H!P``3(GOZ)O1__^#^`-^-DACT+\U6D``N04```!)C705_/.F=2"#^`0/
MA'H&``"#Z`1(F$&`?`7_+P^$:08``&8/'T0``#'`Z#GZ__^%P'46,?9,B>_H
M:]/__X7`B40D(`^%3P$``+[564``OTE90``QP.A>[___Z*G0__](QT0D"'-:
M0`")!"1!N0I90`!)B>BY3EI``$C'PO____^^`0```$B)WS'`Z/G3__]%,>3K
M3`\?0`#H"]#__X,X$75008/$`>A=T/__2,=$)!!S6D``B00D0;D*64``1(ED
M)`A)B>BY7%I``$C'PO____^^`0```$B)WS'`Z*C3__^^P`$``$B)W^CKS___
M@_C_=*9(B>_HGL___TB)WK_R6$``,<#HK^[__TB)W^CG^?__2(G8Z;O]__\/
M'X``````2(G'2(E$)"#HR_G__TB+1"0@2(G'Z`[1___IE?W__[_\64``O0$`
M``#K%0\?1```2&/%@\4!2(M\Q&!(A?]T*TB-="0\,<#H+.W__TB%P'3?@#@`
M=-I(B<?HRM#__TB%P$B)PW3*Z6+[__]`MPV[`5I``.EB^___N@(```!(Q\;N
M____B<=!B<;HJM+__TB-M"2``0``N@8```!$B??HM=#__X"\)(`!````=0Z`
MO"2!`0``0P^$+04``(M\)"`QTC'VZ'#2__^XB:O-[TC'A"0``0```2-%9TC'
MA"08`0``=E0R$$B)A"0(`0``N/[<NIA(QX0D*`$```````!(B80D$`$``+CP
MX=+#2,>$)#`!````````2(F$)"`!``!(C80D.`$``,>$)'@!````````2(E$
M)"B0BWPD($B-M"2``0``N@"```#H"M#__X7`28G'08G$#XZ9`0``2(NT)"@!
M``!)8\>-%,9(.=9(B[0D,`$``'8$2(/&`4C!Z!U(B90D*`$``$@!\$B)A"0P
M`0``2&.$)'@!``"%P`^$1@$``+I`````2(V\!#@!``!(C;0D@`$``"G"03G7
M00].UTQCZD&)U$R)ZNC:S___BX0D>`$``$0!X(/X0(F$)'@!```/A5#___]$
MB?A(C;PD``$``$0IX$&)Q$B-A"2``0``20'%Z'_4__\/'X``````08/\/P^.
MI0```$6)YDV)[P\?A```````28L/2(V\)``!``!!@^Y`28/'0$B)C"0X`0``
M28M/R$B)C"1``0``28M/T$B)C"1(`0``28M/V$B)C"10`0``28M/X$B)C"18
M`0``28M/Z$B)C"1@`0``28M/\$B)C"1H`0``28M/^$B)C"1P`0``Z.S3__]!
M@_X_?X9!@^Q`1(GBP>H&B=#!X@9(@\`!02G42,'@!DD!Q4B+?"0H26/4N4@`
M``!,B>[HQ,[__T2)I"1X`0``Z5?^__\/'X``````3(VL)(`!``#I&____XM\
M)"#H^LW__TR+I"0H`0``3(NL)#`!``!,B>!(P>@#@^`_C4@!2&/0QH04.`$`
M`("#^3@/CW8"``"Z-P```$ACR3'V*<)(C;P,.`$``$ACTNA]S?__3(GH2(V\
M)``!``!$B*PD<P$``$C!Z!A$B*0D=P$``$R-O"30````B(0D<`$``$R)Z$C!
MZ!!-C7<HB(0D<0$``$R)Z$R-K"2Q````2,'H"(B$)'(!``!,B>!(P>@8B(0D
M=`$``$R)X$C!Z!"(A"1U`0``3(G@38G\2,'H"(B$)'8!``#HM=+__TB+A"0`
M`0``2(G"B(0DLP```$C!ZAA$#[;"B)0DL````$B)PDC!ZA"(E"2Q````2(G"
M2(N$)`@!``!(P>H(B)0DL@```$B)PHB$)+<```!(P>H8B)0DM````$B)PDC!
MZA"(E"2U````2(G"2(N$)!`!``!(P>H(B)0DM@```$B)PHB$)+L```!(P>H8
MB)0DN````$B)PDC!ZA"(E"2Y````2(G"2(N$)!@!``!(P>H(B)0DN@```$B)
MPHB$)+\```!(P>H8B)0DO````$B)PDC!ZA"(E"2]````2(G"2(N$)"`!``!(
MP>H(B)0DO@```$B)PHB$),,```!(P>H8B)0DP````$B)PDC!ZA"(E"3!````
M2(G"2,'J"(B4),(```#I$`````\?@`````!%#[9%`$F#Q0%,B><QP+DB6D``
M2,?"_____[X!````28/$`NA`SO__33GT==/&A"3X`````$C'1"0(<UI``$R)
M/"1!N0I90`!)B>BY/UI``$C'PO____^^`0```$B)WS'`Z`+.___I9_K__TV+
M9"0(387D#X2/^?__3(GGZ.?*__](@_@##X9]^?__28UT!/R_.EI``+D%````
M\Z9-#T3LZ6/Y__](8\FZ/P```#'V2(V\##@!```IPDACTN@'R___2(V\)``!
M``#HNM#__TB-E"0X`0``N0<````QP$B)U_-(J^EC_?__@+PD@@$``$$/A<7Z
M__^`O"2#`0``0P^%M_K__X"\)(0!``!(#X6I^O__@+PDA0$``$4/A9OZ__]$
MBW0D(+H"````2,?&QO___T2)]^C_S/__2(VT)(`!``"Z*0```$2)]^@*R___
M2(V$)(`!``!(QT0D"'-:0`!(B00DZ=K^___H"\K__TV++"3I3_C__V:0055!
M5%532(/L&(L]`%X@`.@[R___2(UT)`S&@)D````!ORU90``QP.C3YO__2(7`
M=`F`.#$/A'4"```QP.BN\/__BSW(72``Z`/+__^Y"P```+H!````OFU:0`!(
MB<?HK,K__TB%P`^$O````(,][&T@``%(BT`03(MH*`^.IP```+T(````,=OK
M,@\?1```28MT)!!(BP6\;2``2(L\*.A;RO__A<!U;X/#`8L%KFT@`$B#Q0B-
M4P$YPGUABSU-72``Z(C*__\QR8G:3(GN2(G'Z&G+__](A<!T/$R+($&+1"0,
M)0`$(``]``0``'2@BST:72``Z%7*__],B>:Y`@```#'22(G'Z%/)__](B<;K
M@V8/'T0``(L%0FT@`(U0_SG:#X0G`0``BSWA7"``Z!S*__^Y!````+H!````
MOG):0`!(B<?HQ<G__TB%P$B)PW0S2(M`$(L]LUP@`$B+*.CKR?__NG1:0`!(
MB<=(B>[HR\C__TB+0Q!(BQCV0PY`#X4*`0``BSV$7"``Z+_)__^Y!````+H!
M````OGE90`!(B<?H:,G__TB%P$B)PW0]2(UT)`PQP+_[6$``Z#_E__](A<!(
MB<4/A",!``!(BT,0BSTY7"``2(L8Z'')__](B>I(B<=(B=[H4\C__XL]'5P@
M`.A8R?__2(UT)`S&@)D`````O_)80``QP.CPY/__2(7`2(G#2(D%2VP@``^$
MI0```+[``0``2(G?Z!#'__^#^!%T#(U0`8/Z`0^'Y0```$B#Q!A;74%<05W#
M#Q]``(/X`0^.T/[__[L!````9I"+/:I;(`"#PP'HXLC__TR)[DB)Q^CGQO__
M.1WA:R``?]_IH_[__V8N#Q^$``````"+/7I;(`#HM<C__TB)WDB)Q^@*R?__
MZ=O^__\/'T0``(!X`0`/A(C]__]F#Q]$``#I=OW__P\?`$B+/8EK(`#HK/'_
M_TB%P$B)!8IK(`!T/$B)P^D[____#Q^$``````!(BP5A:R``BST36R``2(LH
M2(M#$$B+&.A$R/__2(GN2(G?Z`GI___IT?[__[]`6T``Z$K(__^)P4B+!2EK
M(`!(B=J_:%M``$B+,#'`Z"_(__\/'T0``&8N#Q^$``````!52(G]4TB#[`CH
MTNS__P^V"$B)PX3)=!I(C5`!#Q]``(#Y+P^V"D@/1-I(@\(!A,EU[C'`Z$?O
M__^%P'0=2(7M=!B`?0``=!*^,%I``$B)W^@[R?__2#G8=`=(@\0(6UW#2(/$
M"$B)[UM=Z8'F__^02(T%*5H@`$B%P'0,2(L-'5H@`.G(QO__,<GK]P\?0`!!
M5T&)_T%628GV055)B=5!5$R-):A5(`!52(TMJ%4@`%-,*>4QVTC!_0-(@^P(
MZ+7$__](A>UT'@\?A```````3(GJ3(GV1(G_0?\4W$B#PP%(.>MUZDB#Q`A;
M74%<05U!7D%?PY!F+@\?A```````\\,``$B#[`A(@\0(PP````$``@`E<R\E
M<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`
M4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%
M4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?
M,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$
M25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%.
M/0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52
M`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S
M)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM``!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M``````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS
M>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@
M*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA
M;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I
M"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?
M1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R
M;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F
M9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@
M=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L
M(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@
M/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@
M,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M
M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W
M-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2
M*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F
M:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H
M*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C
M*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI
M;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@
M)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@````````````````````````#`0P$;`SOD````
M&P```."#__\P`0```(C__Y`%```0BO__``$```"+__]8`0``\*'__Z@!``"P
MHO__"`(``!"C__\H`@``,*7__W@"``"`IO__R`(``!"G___H`@``X*?__R`#
M```0J/__.`,``&"H__]0`P``(*G__W@#```PJ?__D`,``/"J___0`P``(*O_
M_^@#``#@J___&`0``,"M__\X!```(*[__U@$``!0KO__>`0``'"O___(!```
M\+K__Q@%``!`OO__6`4``+"^__^X!0``T+[__]`%``!`O___&`8````````4
M``````````%Z4@`!>!`!&PP'")`!!Q`4````'`````B)__\J````````````
M```4``````````%Z4@`!>!`!&PP'")`!```D````'````*B"__\0!`````X0
M1@X82@\+=PB``#\:.RHS)"(`````3````$0```"@B?__Z18```!"#A"/`D@.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#L@$`\<6#CA!#C!!#BA"#B!"#AA"
M#A!"#@@```````!<````E````$"@__^V`````$(.$(\"0@X8C@-"#B"-!$4.
M*(P%00XPA@9!#CB#!T0.0`)Q"@XX0PXP00XH0@X@0@X80@X00@X(0@M;#CA!
M#C!!#BA"#B!"#AA"#A!"#@@<````]````*"@__]8`````$$.$(,"1PX@`DX.
M$$$."$P````4`0``X*#__QT"````0@X0CP)$#AB.`T(.((T$0@XHC`5$#C"&
M!D$..(,'1PY@`P`!"@XX00XP00XH0@X@0@X80@X00@X(2`L`````3````&0!
M``"PHO__0@$```!"#A"-`D(.&(P#00X@A@1$#BB#!4<.P`%1"@XH00X@00X8
M0@X00@X(20L"UPH.*$$.($$.&$(.$$(."$,+```<````M`$``+"C__^!````
M`$$.$(,":0H."$8+`E`."#0```#4`0``(*3__\@`````0@X0C`))#AB&`TD.
M((,$1PZP(`)Y"@X@00X800X00@X(2`L`````%`````P"``"XI/__*@````!$
M#A!A#@@`%````"0"``#0I/__1`````!$#A![#@@`)````#P"```(I?__N0``
M``!!#A"#`D<.L$`"G@H.$$$."$D+`````!0```!D`@``H*7__P4`````````
M`````#P```!\`@``F*7__[,!````0@X0C0)"#AB,`TD.((8$00XH@P5*#N`@
M`F(*#BA!#B!!#AA"#A!"#@A!"P`````4````O`(``!BG__\D````````````
M```L````U`(``#"G__^_`````$0.$(,"`DP*#@A("P)1"@X(1PM#"@X(00M!
M#@@````<````!`,``,"G___;`0```$0.4`-\`0H."$@+`````!P````D`P``
M@*G__U0`````5`X@<0H."$L+````````'````$0#``#`J?__)`````!$#A!8
M"@X(1`L```````!,````9`,``-"I__\?`0```$(.$(\"0@X8C@-%#B"-!$@.
M*(P%00XPA@9&#CB#!T0.H`$"G@H..$$.,$$.*$(.($(.&$(.$$(."$0+````
M`$P```"T`P``H*K__WX+````0@X0CP)"#AB.`T(.((T$0@XHC`5)#C"&!D$.
M.(,'1P[0@P(#P0(*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P``/`````0$``#0
MM?__00,```!"#A"-`D(.&(P#00X@A@1!#BB#!40.0`,[`@H.*$$.($$.&$(.
M$$(."$4+`````#0```!$!```X+C__V\`````00X0A@)$#AB#`T0.(`)5"@X8
M00X000X(00M$#AA$#A!!#@@`````)````'P$``!H@O__#`(```!!#A"#`D0.
M0`.4`0H.$$,."$$+`````!0```"D!```\+C__QP``````````````$0```"\
M!```^+C__V4`````0@X0CP)%#AB.`T4.((T$10XHC`5(#C"&!D@..(,'30Y`
M;`XX00XP00XH0@X@0@X80@X00@X(`!0````$!0``(+G__P(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````$"1```````#P
M(T```````````````````0`````````!``````````$`````````U@$`````
M```!`````````"4"````````'0````````"#`P````````P`````````^!Q`
M```````-`````````(180```````&0````````#0K6```````!L`````````
M"``````````:`````````-BM8```````'``````````(``````````0`````
M````F`)```````#U_O]O`````+@%0```````!0`````````P$$````````8`
M````````N`9````````*``````````,%````````"P`````````8````````
M`!4````````````````````#``````````"P8````````@``````````!@``
M`````!0`````````!P`````````7`````````/@60```````!P````````"`
M%D````````@`````````>``````````)`````````!@`````````_O__;P``
M````%D```````/___V\``````@````````#P__]O`````#050```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#HK6`````````````````````````````V'4```````$8=
M0```````5AU```````!F'4```````'8=0```````AAU```````"6'4``````
M`*8=0```````MAU```````#&'4```````-8=0```````YAU```````#V'4``
M``````8>0```````%AY````````F'D```````#8>0```````1AY```````!6
M'D```````&8>0```````=AY```````"&'D```````)8>0```````IAY`````
M``"V'D```````,8>0```````UAY```````#F'D```````/8>0```````!A]`
M```````6'T```````"8?0```````-A]```````!&'T```````%8?0```````
M9A]```````!V'T```````(8?0```````EA]```````"F'T```````+8?0```
M````QA]```````#6'T```````.8?0```````]A]````````&($```````!8@
M0```````)B!````````V($```````$8@0```````5B!```````!F($``````
M`'8@0```````AB!```````"6($```````*8@0```````MB!```````#&($``
M`````-8@0```````YB!```````#V($````````8A0```````%B%````````F
M(4````````````````````````````#_____`````+!;0```````1T-#.B`H
M4U5312!,:6YU>"D@-"XX+C4``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"
M22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N:F-R`"YD>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`
M````````````````````````````````````````````````````````````
M```````````````````````````````+`````0````(`````````.`)`````
M```X`@```````!P````````````````````!````````````````````$P``
M``<````"`````````%0"0```````5`(````````@````````````````````
M!````````````````````"$````'`````@````````!T`D```````'0"````
M````)`````````````````````0````````````````````X````!0````(`
M````````F`)```````"8`@```````"`#````````!@`````````(````````
M``0`````````-````/;__V\"`````````+@%0```````N`4``````````0``
M``````8`````````"````````````````````#X````+`````@````````"X
M!D```````+@&````````>`D````````'`````0````@`````````&```````
M``!&`````P````(`````````,!!````````P$`````````,%````````````
M```````!````````````````````3@```/___V\"`````````#050```````
M-!4```````#*``````````8``````````@`````````"`````````%L```#^
M__]O`@``````````%D`````````6````````@``````````'`````@````@`
M``````````````````!J````!`````(`````````@!9```````"`%@``````
M`'@`````````!@`````````(`````````!@`````````=`````0```!"````
M`````/@60```````^!8`````````!@````````8````9````"``````````8
M`````````'X````!````!@````````#X'$```````/@<````````&@``````
M``````````````0```````````````````!Y`````0````8`````````(!U`
M```````@'0```````!`$```````````````````0`````````!``````````
MA`````$````&`````````#`A0```````,"$````````(````````````````
M````"````````````````````(T````!````!@````````!`(4```````$`A
M````````0C<``````````````````!````````````````````"3`````0``
M``8`````````A%A```````"$6`````````D````````````````````$````
M````````````````F0````$````"`````````)!80```````D%@```````"P
M0```````````````````"````````````````````*$````!`````@``````
M``!`F4```````$"9````````Y`````````````````````0`````````````
M``````"O`````0````(`````````*)I````````HF@```````$P%````````
M```````````(````````````````````N0````X````#`````````-"M8```
M````T*T````````(````````````````````"````````````````````,4`
M```/`````P````````#8K6```````-BM````````"```````````````````
M``@```````````````````#1`````0````,`````````X*U@``````#@K0``
M``````@````````````````````(````````````````````U@````8````#
M`````````.BM8```````Z*T````````0`@````````<`````````"```````
M```0`````````(@````!`````P````````#XKV```````/BO````````"```
M``````````````````@`````````"`````````#?`````0````,`````````
M`+!@````````L````````!@"```````````````````(``````````@`````
M````Z`````$````#`````````!BR8```````&+(````````@````````````
M````````"````````````````````.X````(`````P````````!`LF``````
M`#BR````````:!```````````````````"````````````````````#S````
M`0```#`````````````````````XL@```````!@````````````````````!
M``````````$``````````0````,`````````````````````````4+(`````
B``#\`````````````````````0``````````````````````
